/* $Id: serv_chat.h 8004 2009-11-05 15:11:18Z davew $ */
#include "ctdl_module.h"

void ChatUnloadingTest(void);
void allwrite (char *cmdbuf, int flag, char *username);
CitContext *find_context (char **unstr);
void do_chat_listing (int allflag);
void cmd_chat (char *argbuf);
void cmd_pexp (char *argbuf); /* arg unused */
void cmd_sexp (char *argbuf);
void delete_instant_messages(void);
void cmd_gexp(char *);
int send_instant_message(char *, char *, char *, char *);
